function convCondERD = conventionalConditionalERD(eventRelatedTrials, referenceInterval, testStates_Z, kernelWidth) 
% convCondERD = conventionalConditionalERD(eventRelatedTrials, referenceInterval, explanatoryVariable_Z, testStates_Z, kernelWidth) 
%
% computes the conditional ERD using the conventional reference,
% i.e., using a constant baseline.
% 
% ~~~~~~ INPUT ~~~~~
%
% eventRelatedTrials:  struct with at least the following fields
%                        '.x' - (T,C,N) dimensional data tensor of
%                               the observed event-related
%                               bandpass filtered signal power:
%                               leading dimension refers to time;
%                               second dimension to channels, e.g.,
%                               electrodes; third dimension
%                               represents N single trials 
%
%                        '.t' - temporal indices, length must
%                               correspond to first dimension
%                               of '.x'
%
%                        '.z' - (1,N) dimensional row vector
%                               containing the observed explanatory
%                               states variables 
%
% referenceInterval:    (1,2)   vector specifying the reference
%                               interval [tmin,tmax] to be used for
%                               averaging the power in order to get
%                               the constant baseline   
%    (NOTE: tmin, tmax must be provided in the same temporal scale
%           as '.t' above, e.g., in [milli seconds])  
%
% testStates_Z:         (1,S)   optional argument (can be empty)
%                               row vector containing the states of
%                               the explanatory variable Z, where
%                               the empirical estimators should be
%                               evaluated  
% 
% kernelWidth:          (1,N)  optional argument (can be empty)
%                              row vector containing the standard
%                              deviations for the Gaussian kernels
%                              N corresponds to the number of
%                              observed event-related single trials 
% 
% ~~~~ OUTPUT ~~~~~
%
% convCondERD    struct with at least the following fields
%                     '.x' - (T,C,S) dimensional data tensor of the
%                            conventionally estimated conditional ERD:
%                            leading dimension refers to time;
%                            second dimension to channels, e.g.,
%                            electrodes; third dimension
%                            represents S instances spezified in
%                            testStates_Z  
%
%                     '.t' - temporal indices, length corresponds
%                            to first dimension of '.x' 
%
%                     '.z' - (1xS) dimensional row vector of the
%                            corresponding test states
%
%
% Steven Lemm, Berlin, June, 15th, 2009
    
  if ~exist('testStates_Z','var') | isempty(testStates_Z),
    % set the default values for the test states, i.e., do a linear
    % interpolation between minumum and maximum value of the observed
    % explanatory states
    testStates_Z = linspace(min(eventRelatedTrials.z),max(eventRelatedTrials.z),length(eventRelatedTrials.z)) ;
  end ;
  
  numTestStates = length(testStates_Z) ;
  
  if ~exist('kernelWidth','var') | isempty(kernelWidth),
    % set the default values for the kernel width,
    % (cf. supplementary methods for details)
    kernelWidth = (4/3)^0.2 * std([eventRelatedTrials.z])/length(eventRelatedTrials.z)^0.2;
    fprintf('Kernelwidth set to %f\n',kernelWidth);
  end ;

  % get the conditional expected event-related dynamics, evaluated
  % at the test instances 'testStates_Z' 
  convCondERD   = condExpectation(eventRelatedTrials, eventRelatedTrials.z, testStates_Z, kernelWidth) ;

  % get the conditional expected constant baseline, evaluated at
  % the test instances 'testStates_Z'  
  referenceIdx = getIvalIndices(referenceInterval,eventRelatedTrials);
  condStaticRef = mean(convCondERD.x(referenceIdx, :,:),1) ;

  % calculate the conventionally conditional ERD is expressed 
  convCondERD.x = (convCondERD.x./repmat(condStaticRef,[size(convCondERD.x,1),1,1]) -1)*100 ;
  

function iv= getIvalIndices(ival, dat)
%iv= getIvalIndices(ival, dat)
%
% IN   ival - time interval [start ms, end ms] (or just a point of time)
%             ival can also be a 2xN sized matrix. In that case the
%             concatenated indices of all ival-columns are returned.
%      dat  - data struct containing the field .t
%
% OUT  iv   - indices of given interval [samples]

  ibeg= max([1 find(dat.t<=ival(1))]);
  iend= min([find(dat.t>=ival(2)) length(dat.t)]);
  iv= ibeg:iend;

