function [fig_hdl, ax_hdl, cb_hdl]= displayCondERD(condERD, varargin)
% [fig_hdl, ax_hdl, cb_hdl] = displayCondERD(condERD, opt)
% 
% Plot a color contoured image of the state conditional ERD.
%
% ~~~~~~~~INPUTs ~~~~~~
%
% condERD:    struct with at least the following fields
%                     '.x' - (T,C,S) dimensional data tensor of the
%                            estimated conditional ERD:
%                            leading dimension refers to time;
%                            second dimension to channels, e.g.,
%                            electrodes; third dimension
%                            represents S instances spezified in
%                            testStates_Z  
%
%                     '.t' - temporal indices, length corresponds
%                            to first dimension of '.x' 
%
%                     '.z' - (1xS) dimensional row vector of the
%                            corresponding test states
%
% opt:        cellarray or sequence of additional parameter.  In
%                            order to set a particular parameter
%                            first provide the parameter identifier
%                            (name) as string, followed by the
%                            parameter value itself, e.g., 
%         displayCondERD(condERD,'colorbar',0,'title','fancy title');
%
%         the following table provides a list of optional arguments
%         along with a list of possible values
%  
%           idenifier  |  {list of values <default value>}      
%         -------------------------------------------------
%          'transform':  <'linear'>, 'exponential', 'squared'   
%                        can be used to transform the explanatory
%                        variable prior to displaying the ERD,
% 
%          'channel'  :  <1> any number
%                        specifies the channel (electrode) to be displayed
%
%           'xlabel'  : <'time'> any string
%                        provide a label for the horizontal axis
%
%           'ylabel'  : <'explanatory variable'> any string
%                        provide a label for the vertival axis
%
%           'title'   : any string
%                        provide a title for the figure
%
%           'axes'    : handle to an existing axes
%                       use the given axes to display the
%                       conditionl ERD,e.g., in a specific subplot
%
%           'figure'  : handle to an existing figure
%                       use the given figure to display the
%                       conditional ERD  
%
%         'colorbar'  : <1>,0 boolean
%                        attach a colorbar to the figure 
%
%         'colorrange': 'tight' 
%                       uses the interval
%                       [min(condERD),max(condERD)] as the
%                       color range for displaying the ERD 
%                       the default range is  [-100,100]
%
% ~~~~~ OUTPUTs ~~~~~~~~~~~
%
%  fig_hdl: handle to the current figure 
%  ax_hdl : handel to the axes of the contour plot 
%  cb_hdl : handle to the axes of colorbar
%
%
% Steven Lemm, Berlin, June, 15th, 2009

  if mod(nargin,2)==1,

    % default options 
    % for the state variable is 'linear'
    states_Z = condERD.z ;
    % for the color range is [-100 ,100]precent
    c_axis= [-100, 100]; 
    % by default the first channel is displayed
    channel = 1;
    % set default for colorbar 
    putColorbar = 1;
    % set default xLabel
    xLabel = 'time';
    % set default xLabel
    yLabel = 'explanatory variable Z';
    
    numOpts = (nargin-1)/2;
    for opt = 1:numOpts,
      switch lower(varargin{2*opt-1})
       
       case 'transform'
	switch lower(varargin{2*opt})
	 case 'exponential'
	  % for logarithmically transformed state variables it might be
	  % useful to display the original variable by taking the
	  % exponential
	  states_Z = exp(condERD.z) ;
	 case 'squared'
	  % for square root transformed state variables it might be
	  % useful to display the original squared variable
	  % 
	  states_Z = condERD.z.^2 ;
	end ; % end scale axis
	
       case 'channel'
	channel = varargin{2*opt} ;
       
       case 'xlabel'
	xLabel = varargin{2*opt} ;
       
       case 'ylabel'
	yLabel = varargin{2*opt} ;
       
       case 'title'
	titel = varargin{2*opt} ;
	
       case 'axes'
	currentAxis = varargin{2*opt} ;
       
       case 'figure'
	currentFigure = varargin{2*opt} ;
       
       case 'colorbar'
	putColorbar = varargin{2*opt} ;
       
       case 'colorrange'
	switch lower(varargin{2*opt})
	 case 'tight'
	  % for logarithmically transformed state variables it might be
	  % useful to display the original variable by taking the
	  % exponential
	  c_axis= [min(condERD.x(:)),max(condERD.x(:))]; 
	 case 'otherwise'
	  % for square root transformed state variables it might be
	  % useful to display the original squared variable
	  % 
	  c_axis= [-100, 100]; 
	end ; % end color range

      end; % end switch 
    end ; % end loop for opt = 1:numOpts
    
    % prepare the figure to display ERD
    if exist('currentAxis','var'),
      % make the given axes current 
      axes(currentAxis);
    elseif exist('currentFigure','var') ,
      % make the given figure current
      figure(currentFigure) ;
    else
      % no handles given, open a new figure 
      figure;
    end
    
    % get the handles to the current figure and the current axes 
    % those values are the return arguments of the function
    fig_hdl = gcf ; 
    ax_hdl  = gca ;
    
    % make a contour plot of the conditional ERD horizontal axis
    % refers to time, vertical axis corresponds to the explanatory variable
    contourf(condERD.t, states_Z, squeeze(condERD.x(:,channel,:))',256)
    shading('flat');

    % set the color range
    caxis(c_axis) ;
    
    % lable the axis
    ylabel(yLabel,'fontsize',18) ;
    xlabel(xLabel,'fontsize',18) ;
    
    % resize the axis font
    set(gca ,'fontsize',16) ;
    
    % put a colorbar next to it
    if putColorbar,
      cb_hdl = colorbar ;
      % adjust the fontsize of the colorbar
      set(cb_hdl,'fontsize',16);
    else
      % if no colorbar is attached the return value of the handle
      % to the colorbar is set to NaN 
      cb_hdl = NaN; 
    end;
    
    % provide a title to the current axis
    if exist('titel','var'), title(titel); end ;
    
  else % wrong number of arguments passed 
    fprintf('False number of arguments passed.\n');
    error('[fig_hdl, ax_hdl, cb_hdl] = displayCondERD(condERD, opt)');
  end
